<?php
/*
Plugin Name: Universal File Uploader & Downloader
Plugin URI: https://matdan.de
Description: Ermöglicht den Upload und Download von PHP-Dateien über das WordPress-Admin-Menü.
Version: 1.2
Author: Daniel Mattick
License: GPL2
*/

// Sicherheitscheck
if (!defined('ABSPATH')) {
    exit;
}

// Verzeichnis für hochgeladene Dateien definieren
define('PHP_FILE_UPLOAD_DIR', WP_CONTENT_DIR . '/uploads/php-files/');
define('PHP_FILE_UPLOAD_URL', content_url('uploads/php-files/'));

// Admin-Menü hinzufügen
function php_file_uploader_menu() {
    add_menu_page('Universal File Uploader', 'Universal File Uploader', 'manage_options', 'php-file-uploader', 'php_file_uploader_page');
}
add_action('admin_menu', 'php_file_uploader_menu');

// Upload-Formular & Datei-Übersicht anzeigen
function php_file_uploader_page() {
    if (!current_user_can('manage_options')) {
        wp_die(__('Keine Berechtigung.'));
    }

    if (!file_exists(PHP_FILE_UPLOAD_DIR)) {
        wp_mkdir_p(PHP_FILE_UPLOAD_DIR);
    }

    if (isset($_POST['upload_php_file']) && !empty($_FILES['php_file']['name'])) {
        $file = $_FILES['php_file'];
        $file_name = basename($file['name']);
        $file_path = PHP_FILE_UPLOAD_DIR . $file_name;
        
        if (move_uploaded_file($file['tmp_name'], $file_path)) {
            echo '<div class="updated"><p>Datei erfolgreich hochgeladen!</p></div>';
        } else {
            echo '<div class="error"><p>Fehler beim Hochladen.</p></div>';
        }
    }
    
    echo '<div class="wrap"><h2>Universal File Uploader</h2>';
    echo '<form method="post" enctype="multipart/form-data">';
    echo '<input type="file" name="php_file" required> ';
    echo '<button type="submit" name="upload_php_file" class="button button-primary">Hochladen</button>';
    echo '</form>';
    
    echo '<h3>Hochgeladene Dateien</h3><ul>';
    $files = array_merge(glob(PHP_FILE_UPLOAD_DIR . '*.*')); // Zeigt wirklich alle Dateitypen an
    foreach ($files as $file) {
        $file_name = basename($file);
        $file_url = PHP_FILE_UPLOAD_URL . $file_name;
        $shortcode = '[php_download file="' . $file_name . '"]';
        echo '<li><a href="' . $file_url . '" download>' . $file_name . '</a> ';
        echo '<input type="text" value="' . esc_attr($shortcode) . '" readonly onclick="this.select();" style="width: 250px; margin-left: 10px; font-family:monospace;">';
        echo '</li>';
    }
    echo '</ul></div>';
}

// Shortcode zur Anzeige der Download-Liste
function php_file_download_list() {
    $output = '<h3>Downloadbare PHP-Dateien:</h3><ul>';
    $files = array_merge(glob(PHP_FILE_UPLOAD_DIR . '*.*')); // Zeigt wirklich alle Dateitypen an
    
    if (!$files) {
        return '<p>Keine Dateien vorhanden.</p>';
    }
    
    foreach ($files as $file) {
        $file_name = basename($file);
        $file_url = PHP_FILE_UPLOAD_URL . $file_name;
        $output .= '<li><a href="' . $file_url . '" download>' . $file_name . '</a></li>';
    }
    $output .= '</ul>';
    return $output;
}
add_shortcode('php_downloads', 'php_file_download_list');

// Shortcode zur Anzeige eines spezifischen Downloads
function php_file_download_single($atts) {
    $atts = shortcode_atts(['file' => ''], $atts, 'php_download');
    $file_name = basename($atts['file']);
    $file_path = PHP_FILE_UPLOAD_DIR . $file_name;
    
    if (file_exists($file_path) && pathinfo($file_path, PATHINFO_EXTENSION) === 'php') {
        $file_url = PHP_FILE_UPLOAD_URL . $file_name;
        return '<a href="' . $file_url . '" download>' . $file_name . '</a>';
    }
    return '<p>Fehler: Datei nicht gefunden oder falsches Format.</p>';
}
add_shortcode('php_download', 'php_file_download_single');
